# -*- coding: utf-8 -*-

from tuikit.widget import Widget


class MenuBar(Widget):
    def __init__(self, items = []):
        Widget.__init__(self, 0, 1)

        self.allow_focus = True

        self.bg = 'menu'
        self.highlight = 'menu-active'

        self.setitems(items)
        self.selected = None

    def setitems(self, items):
        self.items = items

        i = 0
        for item in self.items:
            if isinstance(item[1], Widget):
                item[1].x = i
                item[1].y = self.y + 1
                item[1].allow_layout = False
                item[1].hidden = True
                item[1].connect('focus', self.on_submenu_focus)
                item[1].menubar = self
            i += len(item[0]) + 4

    def _handle_draw(self, screen, x, y):
        super()._handle_draw(screen, x, y)
        screen.pushcolor(self.bg)
        i = 0
        for item in self.items:
            if self.selected == item:
                screen.pushcolor(self.highlight)
                screen.puts(x + i, y, '  ' + item[0] + '  ')
                screen.popcolor()
            else:
                screen.puts(x + i, y, '  ' + item[0] + '  ')
            i += len(item[0]) + 4
        if i < self.width:
            screen.puts(x + i, y, ' ' * (self.width - i))
        screen.popcolor()


    def _handle_keypress(self, keyname, char):
        super()._handle_draw(keyname, char)
        if keyname == 'left':
            self.move_selected(-1)
        elif keyname == 'right':
            self.move_selected(+1)
        else:
            if self.selected:
                if isinstance(self.selected[1], Widget):
                    self.selected[1].emit('keypress', keyname, char)


    def move_selected(self, offset):
        if self.selected:
            i = self.items.index(self.selected)
            item = self.items[(i + offset) % len(self.items)]
            self.unselect()
            self.select(item)
        self.redraw()

    def _handle_mousedown(self, ev):
        super()._handle_mousedown(ev)
        i = 0
        self.unselect()
        for item in self.items:
            w = len(item[0]) + 4
            if ev.wx >= i and ev.wx < i + w:
                self.select(item)
            i += w

    def _handle_mousemove(self, ev):
        super()._handle_mousemove(ev)
        self.on_mousedown(ev)

    def _handle_unfocus(self, newfocus):
        super()._handle_unfocus()
        if self.selected and newfocus == self.selected[1]:
            return
        self.unselect()

    def on_submenu_focus(self):
        self.set_focus()

    def select(self, item):
        self.selected = item
        if isinstance(item[1], Widget):
            item[1].hidden = False
            item[1].redraw()

    def unselect(self):
        if self.selected:
            if isinstance(self.selected[1], Widget):
                self.selected[1].hidden = True
            self.selected = None

